#
# spec file for package libdatovka
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname %{name}8
Name:           libdatovka
Version:        0.7.0
Release:        1.4
Summary:        Library for accessing the Czech Data Boxes
License:        GPL-3.0-or-later
Group:          System/Libraries
URL:            https://www.datovka.cz/cs/pages/libdatovka.html
Source0:        https://datovka.nic.cz/%{name}/%{name}-%{version}.tar.xz
Source1:        https://datovka.nic.cz/%{name}/%{name}-%{version}.tar.xz.sha256
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-tools

%description
This is a library for accessing ISDS (Informační systém datových schránek /
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%package -n %{libname}
Summary:        Library for accessing the Czech Data Boxes
Group:          System/Libraries

%description -n %{libname}
This is a library for accessing ISDS (Informační systém datových schránek /
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--with-docbook-xsl-stylesheets=/usr/share/xml/docbook/stylesheet/nwalsh/current
%make_build

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -f %{name}.lang

%files -n %{libname}
%license COPYING
%doc AUTHORS
%{_libdir}/*.so.*

%files devel
%doc client
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/isds.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*.3.gz

%changelog
* Mon Sep 30 2024 Jiri Slaby <jslaby@suse.cz>
- update to 0.7.0
  * Assigned explicit values to enum isds_credit_event_type values.
  * Added new value ISDS_CREDIT_DELETED_MESSAGE_RECOVERED and added
  struct isds_credit_event_deleted_message_recovered.
  * Changed URL to new source code download place.
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.2:
  * Using XML_PARSE_NODICT in xmlReadMemory() because of old
    libxml2 versions which may cause segmentation faults.
  * Fixed VoDZ service locator assignment for MEP and TOTP (SMS)
    authentication methods.
  * Fixed parsing of large (mainly VoDZ) ZFO files with recent
    libxml2 versions.
  * Using xmlReadMemory() with XML_PARSE_HUGE option set.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * Added isds_set_xferinfo_callback() as a replacement for
    isds_set_progress_callback(). Marked
    isds_set_progress_callback() as deprecated.
* Mon Dec  4 2023 Jiri Slaby <jslaby@suse.cz>
- update to 0.5.1
  * Added missing test input files into source package.
  * Optimisations inside isds_GetMessageAuthor2(), avoided copying of attribute
  names.
  * Added functions isds_GetListOfErasedMessages_interval(),
  isds_GetListOfErasedMessages_month() and isds_GetListOfErasedMessages_year()
  which implement the GetListOfErasedMessages ISDS operation.
  * Added function isds_PickUpAsyncResponse() which implements the
  PickUpAsyncResponse ISDS operation.
  * Added function isds_load_erased_messages() which can be used to read data
  from a XML-formatted decompressed asynchronous GetListOfErasedMessages
  response. Actual decompression of obtained ZIP-compressed data isn't handled
  by this library.
  * Added support for the new PFO_ARCH, PFO_AIAT and PFO_AZI data-box types
  introduced in the version 3.04 of the XSD and WSDL definitions.
  * Added new elements dmFileGuid and dmUpFileGuid into struct isds_dmFile and
  struct isds_dmExtFile.
* Wed Sep 20 2023 Jiri Slaby <jslaby@suse.cz>
- update to 0.4.0
  * Added functions for new ISDS services
  * Added variants of function for services
  * Added new elements dmVODZ and attsNum into struct isds_envelope.
  * Added new element ext_files into struct isds_message.
  * Fixed compilation of simline/server_cli with musl libc.
  * Favouring xmlBufferDetach() over setting XML_BUFFER_ALLOC_IMMUTABLE.
* Fri Mar  3 2023 Jiri Slaby <jslaby@suse.cz>
- update to 0.3.0
  * Added idLevel member into struct isds_envelope.
  * Added function isds_GetMessageAuthor2() which implements the
  GetMessageAuthor2 ISDS operation and corresponding data structures.
  * Modified the interface of function isds_set_opt() because of an ambiguity or
  undefined behaviour in variable argument handling in C.
  * Function isds_check_func_timegm() also checks time conversion using
  struct tm containing negative hour values.
  * Added support for the new PFO_REQ data-box type
  introduced in the version 2.36 of the XSD and WSDL definitions.
  * Disabled fatal warnings by default.
* Mon Nov 15 2021 Jiri Slaby <jslaby@suse.cz>
- update to 0.2.1
  * Added function isds_DTInfo() which implements the DTInfo ISDS operation
    and corresponding data structures.
* Mon Aug 30 2021 Jiri Slaby <jslaby@suse.cz>
- update to 0.2.0
  * Added function isds_PDZSendInfo() which supports the PDZSendInfo ISDS
  operation.
  * Using struct isds_timeval instead of struct timeval in the library interface.
  The new structure always uses 64-bit integers for seconds.
  * Added functions to provide own time conversion functions for example in
  situations in which the target system suffers from the year 2038 problem.
  * Fixed memory leak inside isds_get_received_envelope().
  * Fixed memory leaks in code located in client/ and test/offline/ directories.
* Fri Apr 23 2021 Jiri Slaby <jslaby@suse.cz>
- update to 0.1.2
  * Added support for the new PFO_ZNALEC and PFO_TLUMOCNIK data-box types.
  * Fixed found typos in documentation and commentaries in sources.
* Fri Mar 19 2021 Jiri Slaby <jslaby@suse.cz>
- move .lang to the main rpm (to avoid conflicts of w/ multiple libs)
* Mon Mar  1 2021 Jiri Slaby <jslaby@suse.cz>
- initial version (0.1.1)
